import phonenumbers


def prefix(phone_number):
    try:
        parsed_number = phonenumbers.parse(f'+{phone_number}', None)
        if phonenumbers.is_valid_number(parsed_number):
            prefix = str(parsed_number.country_code)
            number = str(parsed_number.national_number)
            return prefix, number
        else:
            return None, None
    except phonenumbers.phonenumberutil.NumberParseException:
        return None, None


def code(phone_number):
    try:
        parsed_number = phonenumbers.parse(f'+{phone_number}', None)
        country_code = phonenumbers.region_code_for_number(parsed_number)
        number = str(parsed_number.national_number)
        return country_code, number
    except phonenumbers.phonenumberutil.NumberParseException:
        return None, None



import time
from requests import JSONDecodeError
import requests
import random
from automation_utilities import Exceptions
from automation_utilities.Generator import generate_email, generate_password


def domains():
    return [element['domain'] for element in requests.get('https://api.mail.tm/domains').json()['hydra:member']]


class Account:

    def __init__(
            self,
            address: str = generate_email(random.choice(domains())),
            password: str = generate_password()
    ):
        self.address = address
        self.password = password
        data = {
            'address': address.lower(),
            'password': password
        }
        while True:
            try:
                self.id = requests.post('https://api.mail.tm/accounts', json=data).json()['id']
                break
            except KeyError:
                raise Exceptions.AccountError()
            except JSONDecodeError:
                pass
        while True:
            try:
                token = requests.post('https://api.mail.tm/token', json=data).json()['token']
                break
            except JSONDecodeError:
                pass
        self.headers = {'Authorization': f"Bearer {token}"}

    def messages(self, timeout: float = 30):
        start = time.time()
        while True:
            while True:
                try:
                    resoponse = requests.get('https://api.mail.tm/messages', headers=self.headers).json()
                    break
                except JSONDecodeError:
                    pass
                if time.time() - start > timeout:
                    raise TimeoutError
            if resoponse['hydra:totalItems'] > 0:
                messages = []
                for member in resoponse['hydra:member']:
                    url = f'https://api.mail.tm/messages/{member["id"]}'
                    while True:
                        try:
                            messages.append(requests.get(url, headers=self.headers).json()['html'])
                            break
                        except JSONDecodeError:
                            pass
                if resoponse['hydra:totalItems'] == 1:
                    return messages[0][0]
                else:
                    return messages[0]
            if time.time() - start > timeout:
                raise TimeoutError



class Proxy:
    def __init__(
            self,
            server: str | None = None,
            port: str | None = None,
            username: str | None = None,
            password: str | None = None,
            information: list[str] | None = None
    ):
        if information is None:
            self.server = server
            self.port = port
            self.username = username
            self.password = password
        else:
            self.server, self.port, self.username, self.password = information

    def __call__(self, *types: str):
        if len(types) == 0:
            types = ('http', 'https')
        return {
            f'{proxy_type}':
                f'{proxy_type}://{self.username}:{self.password}@{self.server}:{self.port}' for proxy_type in types
        }



import os
import threading

lock = threading.Lock()


def add(text: str, to: str) -> None:
    lock.acquire()
    open(to, 'a').write(text)
    lock.release()


def load(*file_names: str):
    lists = []
    for file_name in file_names:
        try:
            lists.append(open(file_name, 'r').read().strip().split('\n'))
        except FileNotFoundError:
            open(file_name, 'w').write('')
            lists.append([])
    return lists if len(lists) > 1 else lists[0]


def delete(text: str, from_file: str):
    with open(from_file, "r") as file_input:
        with open("temp.txt", "w") as output:
            for line in file_input.readlines():
                if line != text:
                    output.write(line)
    os.replace('temp.txt', from_file)



import random
import string
from names import get_first_name


def generate_email(domain: str, name: str = get_first_name(), username_length: int = random.randint(10, 15)):
    return f'{name}{"".join(random.choice(string.digits) for _ in range(username_length - len(name)))}@{domain}'


def generate_password(length: int = random.randint(10, 20)):
    return ''.join(random.choice(string.ascii_letters + string.digits) for _ in range(length))



from setuptools import setup

setup(
    name='automation-utilities',
    version='1.4.3',
    author='Hazem Oukal',
    description='Some automation tools',
    packages=['automation_utilities'],
    install_requires=['phonenumbers', 'names', 'requests'],
)
